#######################################################################
# tc_pingicmp.rb
#
# Test case for the Net::PingICMP class.  You must run this test case
# with root privileges on UNIX systems. This should be run via the
# 'test' or 'test_icmp' Rake task.
#######################################################################
require "test/unit"
require "net/ping/icmp"
include Net

unless Process.euid == 0
   raise "The test_icmp task must be run with root privileges"
end

class TC_PingICMP < Test::Unit::TestCase
   def setup
      @host = "www.ruby-lang.org"
      @icmp = Ping::ICMP.new(@host)
   end

   def test_version
      assert_equal("1.2.1", PingICMP::VERSION)
   end
   
   def test_ping
      assert_respond_to(@icmp, :ping)
      assert_nothing_raised{ @icmp.ping }
      assert_nothing_raised{ @icmp.ping(@host) }
   end

   def test_ping_aliases
      assert_respond_to(@icmp, :ping?)
      assert_respond_to(@icmp, :pingecho)
      assert_nothing_raised{ @icmp.ping? }
      assert_nothing_raised{ @icmp.ping?(@host) }
      assert_nothing_raised{ @icmp.pingecho }
      assert_nothing_raised{ @icmp.pingecho(@host) }
   end

   def test_bind
      assert_respond_to(@icmp, :bind)
      assert_nothing_raised{ @icmp.bind(Socket.gethostname) }
      assert_nothing_raised{ @icmp.bind(Socket.gethostname, 80) }
   end

   def test_duration
      assert_nothing_raised{ @icmp.ping }
      assert_respond_to(@icmp, :duration)
      assert_kind_of(Float, @icmp.duration)
   end

   def test_host
      assert_respond_to(@icmp, :host)
      assert_respond_to(@icmp, :host=)
      assert_equal('www.ruby-lang.org', @icmp.host)
   end

   def test_port
      assert_respond_to(@icmp, :port)
      assert_equal(nil, @icmp.port)
   end

   def test_timeout
      assert_respond_to(@icmp, :timeout)
      assert_respond_to(@icmp, :timeout=)
      assert_equal(5, @icmp.timeout)
   end

   def test_exception
      assert_respond_to(@icmp, :exception)
      assert_nothing_raised{ @icmp.ping }
      assert_nil(@icmp.exception)
   end

   def test_warning
      assert_respond_to(@icmp, :warning)
   end

   def teardown
      @host = nil
      @icmp = nil
   end
end
